@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2020 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone.
+ * This file is part of Liblinphone 
+ * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -146,15 +147,31 @@ LINPHONE_PUBLIC void linphone_account_params_set_expires(LinphoneAccountParams *
  * Indicates  either or not, REGISTRATION must be issued for this #LinphoneAccountParams.
  * @param params #LinphoneAccountParams object. @notnil
  * @param enable If TRUE, registration will be engaged.
+ * @deprecated 16/12/2021 Use linphone_account_params_enable_register() instead.
  */
 LINPHONE_PUBLIC void linphone_account_params_set_register_enabled(LinphoneAccountParams *params, bool_t enable);
 
+/**
+ * Indicates  either or not, REGISTRATION must be issued for this #LinphoneAccountParams.
+ * @param params #LinphoneAccountParams object. @notnil
+ * @param enable If TRUE, registration will be engaged.
+ */
+LINPHONE_PUBLIC void linphone_account_params_enable_register(LinphoneAccountParams *params, bool_t enable);
+
+/**
+ * Indicates either or not, PUBLISH must be issued for this #LinphoneAccountParams.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param enable If TRUE, publish will be engaged.
+ * @deprecated 16/12/2021 Use linphone_account_params_enable_publish() instead.
+ */
+LINPHONE_PUBLIC void linphone_account_params_set_publish_enabled(LinphoneAccountParams *params, bool_t enable);
+
 /**
  * Indicates either or not, PUBLISH must be issued for this #LinphoneAccountParams.
  * @param params The #LinphoneAccountParams object. @notnil
  * @param enable If TRUE, publish will be engaged.
  */
-LINPHONE_PUBLIC void linphone_account_params_set_publish_enabled(LinphoneAccountParams *params, bool_t enable);
+LINPHONE_PUBLIC void linphone_account_params_enable_publish(LinphoneAccountParams *params, bool_t enable);
 
 /**
  * Set the publish expiration time in second.
@@ -175,9 +192,18 @@ LINPHONE_PUBLIC int linphone_account_params_get_publish_expires(const LinphoneAc
  * #linphone_core_invite).
  * @param params The #LinphoneAccountParams object. @notnil
  * @param enable TRUE to replace + by the international prefix, FALSE otherwise.
+ * @deprecated 16/12/2021 Use linphone_account_params_enable_dial_escape_plus() instead.
 **/
 LINPHONE_PUBLIC void linphone_account_params_set_dial_escape_plus_enabled(LinphoneAccountParams *params, bool_t enable);
 
+/**
+ * Set whether liblinphone should replace "+" by international calling prefix in dialed numbers (passed to
+ * #linphone_core_invite).
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param enable TRUE to replace + by the international prefix, FALSE otherwise.
+**/
+LINPHONE_PUBLIC void linphone_account_params_enable_dial_escape_plus(LinphoneAccountParams *params, bool_t enable);
+
 /**
  * Set an international prefix to be automatically prepended when inviting a number with
  * linphone_core_invite();
@@ -198,15 +224,31 @@ LINPHONE_PUBLIC void linphone_account_params_set_use_international_prefix_for_ca
  * Indicates whether quality statistics during call should be stored and sent to a collector according to RFC 6035.
  * @param params The #LinphoneAccountParams object. @notnil
  * @param enable TRUE to store quality statistics and send them to the collector, FALSE to disable it.
+ * @deprecated 16/12/2021 Use linphone_account_params_enable_quality_reporting() instead.
  */
 LINPHONE_PUBLIC void linphone_account_params_set_quality_reporting_enabled(LinphoneAccountParams *params, bool_t enable);
 
+ /**
+ * Indicates whether quality statistics during call should be stored and sent to a collector according to RFC 6035.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param enable TRUE to store quality statistics and send them to the collector, FALSE to disable it.
+ */
+LINPHONE_PUBLIC void linphone_account_params_enable_quality_reporting(LinphoneAccountParams *params, bool_t enable);
+
+/**
+ * Indicates whether quality statistics during call should be stored and sent to a collector according to RFC 6035.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return TRUE if quality repotring is enabled, FALSE otherwise.
+ * @deprecated 16/12/2021 Use linphone_account_params_quality_reporting_enabled() instead.
+ */
+LINPHONE_PUBLIC bool_t linphone_account_params_get_quality_reporting_enabled(const LinphoneAccountParams *params);
+
 /**
  * Indicates whether quality statistics during call should be stored and sent to a collector according to RFC 6035.
  * @param params The #LinphoneAccountParams object. @notnil
  * @return TRUE if quality repotring is enabled, FALSE otherwise.
  */
-LINPHONE_PUBLIC bool_t linphone_account_params_get_quality_reporting_enabled(const LinphoneAccountParams *params);
+LINPHONE_PUBLIC bool_t linphone_account_params_quality_reporting_enabled(const LinphoneAccountParams *params);
 
  /**
  * Set the route of the collector end-point when using quality reporting. This SIP address
@@ -293,9 +335,17 @@ LINPHONE_PUBLIC const char *linphone_account_params_get_identity(const LinphoneA
  * Tell if the PUBLISH is enabled.
  * @param params The #LinphoneAccountParams object. @notnil
  * @return TRUE if PUBLISH request is enabled for this proxy.
+ * @deprecated 16/12/2021 Use linphone_account_params_publish_enabled() instead.
 **/
 LINPHONE_PUBLIC bool_t linphone_account_params_get_publish_enabled(const LinphoneAccountParams *params);
 
+/**
+ * Tell if the PUBLISH is enabled.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return TRUE if PUBLISH request is enabled for this proxy.
+**/
+LINPHONE_PUBLIC bool_t linphone_account_params_publish_enabled(const LinphoneAccountParams *params);
+
 /**
  * Get the account params proxy address.
  * @param params The #LinphoneAccountParams object. @notnil
@@ -322,9 +372,17 @@ LINPHONE_PUBLIC int linphone_account_params_get_expires(const LinphoneAccountPar
  * Returns whether the account params is enabled or not.
  * @param params The #LinphoneAccountParams object. @notnil
  * @return TRUE if registration to the proxy is enabled.
+ * @deprecated 16/12/2021 Use linphone_account_params_register_enabled() instead.
 **/
 LINPHONE_PUBLIC bool_t linphone_account_params_get_register_enabled(const LinphoneAccountParams *params);
 
+/**
+ * Returns whether the account params is enabled or not.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return TRUE if registration to the proxy is enabled.
+**/
+LINPHONE_PUBLIC bool_t linphone_account_params_register_enabled(const LinphoneAccountParams *params);
+
 /**
  * Returns the contact parameters.
  * @param params The #LinphoneAccountParams object. @notnil
@@ -363,9 +421,17 @@ LINPHONE_PUBLIC const char* linphone_account_params_get_contact_uri_parameters(c
  * Return whether or not the + should be replaced by 00.
  * @param params The #LinphoneAccountParams object. @notnil
  * @return Whether liblinphone should replace "+" by "00" in dialed numbers (passed to #linphone_core_invite()).
+ * @deprecated 16/12/2021 Use linphone_account_params_dial_escape_plus_enabled() instead.
 **/
 LINPHONE_PUBLIC bool_t linphone_account_params_get_dial_escape_plus_enabled(const LinphoneAccountParams *params);
 
+/**
+ * Return whether or not the + should be replaced by 00.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return Whether liblinphone should replace "+" by "00" in dialed numbers (passed to #linphone_core_invite()).
+**/
+LINPHONE_PUBLIC bool_t linphone_account_params_dial_escape_plus_enabled(const LinphoneAccountParams *params);
+
 /**
  * Get the prefix set for this account params.
  * @param params The #LinphoneAccountParams object. @notnil
@@ -504,19 +570,43 @@ LINPHONE_PUBLIC void linphone_account_params_set_nat_policy(LinphoneAccountParam
  */
 LINPHONE_PUBLIC void linphone_account_params_set_conference_factory_uri(LinphoneAccountParams *params, const char *uri);
 
+/**
+ * Set the audio video conference factory uri.
+ * @param params The #LinphoneAccountParams object @notnil
+ * @param address The #LinphoneAddress to set. @maybenil
+ * @param uri The uri of the audio video conference factory. @maybenil
+ */
+LINPHONE_PUBLIC void linphone_account_params_set_audio_video_conference_factory_address(LinphoneAccountParams *params, const LinphoneAddress *address);
+
+/**
+ * If enabled, the proxy will be used as the only route.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param enable TRUE to enable, FALSE otherwise.
+ * @deprecated 16/12/2021 Use linphone_account_params_enable_outbound_proxy() instead.
+ */
+LINPHONE_PUBLIC void linphone_account_params_set_outbound_proxy_enabled(LinphoneAccountParams *params, bool_t enable);
+
 /**
  * If enabled, the proxy will be used as the only route.
  * @param params The #LinphoneAccountParams object. @notnil
  * @param enable TRUE to enable, FALSE otherwise.
  */
-LINPHONE_PUBLIC void linphone_account_params_set_outbound_proxy_enabled(LinphoneAccountParams *params, bool_t enable);
+LINPHONE_PUBLIC void linphone_account_params_enable_outbound_proxy(LinphoneAccountParams *params, bool_t enable);
+
+/**
+ * Tell if the proxy is used as the only route.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return enable TRUE if enabled, FALSE otherwise.
+ * @deprecated 16/12/2021 Use linphone_account_params_outbound_proxy_enabled() instead.
+ */
+LINPHONE_PUBLIC bool_t linphone_account_params_get_outbound_proxy_enabled(const LinphoneAccountParams *params);
 
 /**
  * Tell if the proxy is used as the only route.
  * @param params The #LinphoneAccountParams object. @notnil
  * @return enable TRUE if enabled, FALSE otherwise.
  */
-LINPHONE_PUBLIC bool_t linphone_account_params_get_outbound_proxy_enabled(const LinphoneAccountParams *params);
+LINPHONE_PUBLIC bool_t linphone_account_params_outbound_proxy_enabled(const LinphoneAccountParams *params);
 
 /**
  * Get the conference factory uri.
@@ -525,6 +615,13 @@ LINPHONE_PUBLIC bool_t linphone_account_params_get_outbound_proxy_enabled(const
  */
 LINPHONE_PUBLIC const char* linphone_account_params_get_conference_factory_uri(const LinphoneAccountParams *params);
 
+/**
+ * Get the audio video conference factory uri.
+ * @param params The #LinphoneAccountParams object @notnil
+ * @return The #LinphoneAddress of the audio video conference factory. @maybenil
+ */
+LINPHONE_PUBLIC const LinphoneAddress* linphone_account_params_get_audio_video_conference_factory_address(const LinphoneAccountParams *params);
+
 /**
  * Indicates whether to add to the contact parameters the push notification information. For IOS, it indicates for VOIP push notification.
  * @param params The #LinphoneAccountParams object. @notnil
@@ -588,6 +685,112 @@ LINPHONE_PUBLIC void linphone_account_params_set_transport(LinphoneAccountParams
  */
 LINPHONE_PUBLIC LinphoneTransportType linphone_account_params_get_transport(const LinphoneAccountParams *params);
 
+/**
+ * Enables or disables RTP bundle mode (Media Multiplexing).
+ * See https://datatracker.ietf.org/doc/html/rfc8843 for more information about the feature.
+ * When enabled, liblinphone will try to negociate the use of a single port for all streams when doing an outgoing call.
+ * It automatically enables rtcp-mux.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param value a boolean to indicate whether the feature is to be enabled.
+ *
+ */
+LINPHONE_PUBLIC void linphone_account_params_enable_rtp_bundle(LinphoneAccountParams *params, bool_t value);
+
+/**
+ * Returns whether RTP bundle mode (also known as Media Multiplexing) is enabled.
+ * See https://datatracker.ietf.org/doc/html/rfc8843 for more information.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return a boolean indicating the enablement of rtp bundle mode.
+ */
+LINPHONE_PUBLIC bool_t linphone_account_params_rtp_bundle_enabled(const LinphoneAccountParams *params);
+
+/**
+ * Indicates whether support of rtp bundle is assumed.
+ * See linphone_account_params_enable_rtp_bundle() for background information about rtp bundle.
+ * Assumption that RTP bundling support allows interesting optimizations, such as
+ * not gathering RTCP candidates, and not gathering candidates for video stream when making
+ * an outgoing call.
+ * This setting is meaningful only if rtp bundle is enabled.
+ * See https://datatracker.ietf.org/doc/html/rfc8843 for more information about the feature.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param value a boolean to indicate whether RTP bundle support can be assumed.
+ *
+ */
+LINPHONE_PUBLIC void linphone_account_params_enable_rtp_bundle_assumption(LinphoneAccountParams *params, bool_t value);
+
+/**
+ * Returns whether RTP bundle mode is assumed.
+ * See https://datatracker.ietf.org/doc/html/rfc8843 for more information.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return a boolean indicating when rtp bundle support is assumed.
+ */
+LINPHONE_PUBLIC bool_t linphone_account_params_rtp_bundle_assumption_enabled(const LinphoneAccountParams *params);
+
+/**
+ * Indicates whether chat messages sent by this account in a #LinphoneChatRoomBackendBasic chat room will be using CPIM format or not.
+ * By default SIP SIMPLE format is used for "basic" chat rooms, CPIM is only used for #LinphoneChatRoomBackendFlexisipChat chat rooms.
+ * @see https://wiki.linphone.org/xwiki/wiki/public/view/Lib/Features/Instant%20Messaging/Reply%20to%20a%20specific%20message/
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return TRUE if chat messages will be sent out in CPIM format, FALSE if chat messages will be sent out as SIP SIMPLE.
+ */
+LINPHONE_PUBLIC bool_t linphone_account_params_cpim_in_basic_chat_room_enabled(const LinphoneAccountParams *params);
+
+/**
+ * Indicates whether chat messages sent by this account in a #LinphoneChatRoomBackendBasic chat room will be using CPIM format or not.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param enable TRUE to send messages in CPIM format, FALSE to keep using the SIP SIMPLE format.
+ */
+LINPHONE_PUBLIC void linphone_account_params_enable_cpim_in_basic_chat_room(LinphoneAccountParams *params, bool_t enable);
+
+/**
+ * Set one custom parameter to this #LinphoneAccountParams.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param key key of the searched parameter. @notnil
+ * @param value value of the searched parameter. @notnil
+ */
+LINPHONE_PUBLIC void linphone_account_params_add_custom_param(LinphoneAccountParams *params, const char * key, const char * value);
+
+/**
+ * Get the custom parameter with key to this #LinphoneAccountParams.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param key key of the searched parameter. @notnil
+ * @return The value of the parameter with key if found or an empty string otherwise. @notnil
+ */
+LINPHONE_PUBLIC const char * linphone_account_params_get_custom_param(const LinphoneAccountParams *params, const char * key);
+
+
+/**
+ * Set a an optional custom contact address to be used when registering to the SIP server.
+ * This is typically used to supply an alternative SIP address to call in case the main one is not reachable.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param contact a #LinphoneAddress the optional alternative contact address. @maybenil
+ */
+LINPHONE_PUBLIC void linphone_account_params_set_custom_contact(LinphoneAccountParams *params, const LinphoneAddress *contact);
+
+/**
+ * Get the custom contact address previously used when registering to the SIP server.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return a #LinphoneAddress @maybenil
+ */
+LINPHONE_PUBLIC const LinphoneAddress * linphone_account_params_get_custom_contact(const LinphoneAccountParams *params);
+
+/**
+ * Set the x3dh server url.
+ * If empty, this function will disable LIME X3DH from core.
+ * Otherwise, or if different from the existing value, this will (re-)initialize the LIME X3DH engine.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @param url The x3dh server url. @maybenil
+**/
+LINPHONE_PUBLIC void linphone_account_params_set_lime_server_url(LinphoneAccountParams *params, const char *url);
+
+/**
+ * Get the x3dh server url.
+ * @param params The #LinphoneAccountParams object. @notnil
+ * @return The x3dh server url. @maybenil
+**/
+LINPHONE_PUBLIC const char *linphone_account_params_get_lime_server_url(const LinphoneAccountParams *params);
+
+
 /**
  * @}
  */
