@@ -258,6 +258,25 @@ LINPHONE_PUBLIC LinphoneCallCbsCameraNotWorkingCb linphone_call_cbs_get_camera_n
  */
 LINPHONE_PUBLIC void linphone_call_cbs_set_camera_not_working(LinphoneCallCbs *cbs, LinphoneCallCbsCameraNotWorkingCb cb);
 
+/**
+ * Get the callback that will be used to notify that there are errors from the video rendering.
+ * Check #LinphoneCallCbsVideoDisplayErrorOccurredCb for more details.
+ *
+ * @param cbs The #LinphoneCallCbs object. @notnil
+ * @return The failing rendering callback.
+ */
+LINPHONE_PUBLIC LinphoneCallCbsVideoDisplayErrorOccurredCb linphone_call_cbs_get_video_display_error_occurred(const LinphoneCallCbs *cbs);
+
+/**
+ * Set the callback that will be used to notify that there are errors from the video rendering.
+ * Check #LinphoneCallCbsVideoDisplayErrorOccurredCb for more details.
+ *
+ * @param cbs The #LinphoneCallCbs object. @notnil
+ * @param[in] cb The failing rendering callback to be used.
+ */
+LINPHONE_PUBLIC void linphone_call_cbs_set_video_display_error_occurred(LinphoneCallCbs *cbs,
+                                                              LinphoneCallCbsVideoDisplayErrorOccurredCb cb);
+
 /**
  * Get the audio device changed callback.
  * @param cbs The #LinphoneCallCbs object. @notnil
