@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone.
+ * This file is part of Liblinphone 
+ * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -77,7 +78,7 @@ LINPHONE_PUBLIC LinphoneChatMessage* linphone_chat_room_create_message_from_utf8
 
  /**
  * Creates a message attached to the given chat room with a particular content.
- * Use linphone_chat_room_send_message() to initiate the transfer
+ * Use linphone_chat_message_send() to initiate the transfer
  * @param chat_room the #LinphoneChatRoom object. @notnil
  * @param initial_content #LinphoneContent initial content. @notnil
  * @return a new #LinphoneChatMessage @notnil
@@ -98,7 +99,16 @@ LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_room_create_forward_message (
  * @param message #LinphoneChatMessage message to reply to. @notnil
  * @return a new #LinphoneChatMessage @notnil
  */
-LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_room_create_reply_message (LinphoneChatRoom *cr, LinphoneChatMessage *message);
+LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_room_create_reply_message (LinphoneChatRoom *chat_room, LinphoneChatMessage *message);
+
+ /**
+ * Creates a chat message with a voice recording attached to the given chat room.
+ * @warning If the recorder isn't in Closed state, it will return an empty message!
+ * @param chat_room the #LinphoneChatRoom object. @notnil
+ * @param recorder the #LinphoneRecorder object used to record the voice message. @notnil
+ * @return a new #LinphoneChatMessage @notnil
+ */
+LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_room_create_voice_recording_message (LinphoneChatRoom *chat_room, LinphoneRecorder *recorder);
 
 /**
  * Get the peer address associated to this chat room.
@@ -128,26 +138,32 @@ LINPHONE_PUBLIC void linphone_chat_room_receive_chat_message (LinphoneChatRoom *
 LINPHONE_PUBLIC void linphone_chat_room_mark_as_read(LinphoneChatRoom *chat_room);
 
 /**
- * Enable or disable the ephemeral message feature in the chat room. Works only for conference based chat room.
- * An ephemeral message will automatically disappear from the recipient's schat_roomeen after the message has been viewed.
+ * Enable or disable the ephemeral message feature in the chat room. Works only for flexisip-based chat room.
+ * An ephemeral message will automatically disappear from the sender and recipient's chatrooms after a specified 
+ * timeout configurable with linphone_chat_room_set_ephemeral_lifetime().
+ * The timer starts when the message has been displayed at the recipent, which means:
+ * - at recipient side when linphone_chat_room_mark_as_read() is called.
+ * - at sender side, when the message enters the state LinphoneChatMessageStateDisplayed (when receiving the displayed IMDN).
+ * 
  * @param chat_room #LinphoneChatRoom object @notnil
  * @param enable TRUE if the ephemeral message feature is enabled, FALSE otherwise.
  */
-LINPHONE_PUBLIC void linphone_chat_room_enable_ephemeral (LinphoneChatRoom *chat_room, bool_t enable);
+LINPHONE_PUBLIC void linphone_chat_room_enable_ephemeral(LinphoneChatRoom *chat_room, bool_t enable);
 
 /**
  * Returns whether or not the ephemeral message feature is enabled in the chat room.
  * @param chat_room The #LinphoneChatRoom object corresponding to the conversation @notnil
  * @return TRUE if ephemeral is enabled, FALSE otherwise.
  */
-LINPHONE_PUBLIC bool_t linphone_chat_room_ephemeral_enabled (const LinphoneChatRoom *chat_room);
+LINPHONE_PUBLIC bool_t linphone_chat_room_ephemeral_enabled(const LinphoneChatRoom *chat_room);
 
 /**
- * Set lifetime (in seconds) for all new ephemral messages in the chat room.
+ * Set lifetime (in seconds) for all new ephemeral messages in the chat room.
  * After the message is read, it will be deleted after "time" seconds.
  * @see linphone_chat_room_ephemeral_enabled()
  * @param chat_room #LinphoneChatRoom object @notnil
- * @param time The ephemral lifetime, default 24h, 86400s
+ * @param time The ephemeral lifetime, default is 0 (disabled)
+ * @warning A value of "time" equal to 0 disables ephemeral messages
  */
 LINPHONE_PUBLIC void linphone_chat_room_set_ephemeral_lifetime (LinphoneChatRoom *chat_room, long time);
 
@@ -160,6 +176,24 @@ LINPHONE_PUBLIC void linphone_chat_room_set_ephemeral_lifetime (LinphoneChatRoom
  */
 LINPHONE_PUBLIC long linphone_chat_room_get_ephemeral_lifetime (const LinphoneChatRoom *chat_room);
 
+/**
+ * Set the ephemeral mode of the chat room
+ * @see linphone_chat_room_ephemeral_enabled()
+ * @param chat_room #LinphoneChatRoom object @notnil
+ * @param mode The ephemeral mode #LinphoneChatRoomEphemeralMode
+ * @warning This function only changes the mode of ephemeral messages #LinphoneChatRoomEphemeralMode. It is required to manually enable ephemeral messages after setting the mode by calling linphone_chat_room_enable_ephemeral()
+ */
+LINPHONE_PUBLIC void linphone_chat_room_set_ephemeral_mode (LinphoneChatRoom *chat_room, LinphoneChatRoomEphemeralMode mode);
+
+/**
+ * Get the ephemeral mode of the chat room.
+ * @see linphone_chat_room_ephemeral_enabled()
+ * @param chat_room #LinphoneChatRoom object @notnil
+ * @return the ephemeral mode #LinphoneChatRoomEphemeralMode
+ */
+LINPHONE_PUBLIC LinphoneChatRoomEphemeralMode linphone_chat_room_get_ephemeral_mode (const LinphoneChatRoom *chat_room);
+
+
 /**
  * Uses linphone spec to check if all participants support ephemeral messages.
  * It doesn't prevent to send ephemeral messages in the room but those who don't support it
@@ -215,6 +249,13 @@ LINPHONE_PUBLIC bctbx_list_t *linphone_chat_room_get_history (LinphoneChatRoom *
  */
 LINPHONE_PUBLIC bctbx_list_t *linphone_chat_room_get_history_range (LinphoneChatRoom *chat_room, int begin, int end);
 
+/**
+ * Gets all unread messages for this chat room, sorted from oldest to most recent.
+ * @param chat_room The #LinphoneChatRoom object corresponding to the conversation for which messages should be retrieved @notnil
+ * @return A list of unread chat messages. \bctbx_list{LinphoneChatMessage} @tobefreed
+ */
+LINPHONE_PUBLIC bctbx_list_t *linphone_chat_room_get_unread_history (LinphoneChatRoom *chat_room);
+
 /**
  * Gets nb_events most recent chat message events from chat_room chat room, sorted from oldest to most recent.
  * @param chat_room The #LinphoneChatRoom object corresponding to the conversation for which events should be retrieved @notnil
@@ -300,7 +341,7 @@ LINPHONE_PUBLIC LinphoneCore* linphone_chat_room_get_core(const LinphoneChatRoom
 
 /**
  * When realtime text is enabled linphone_call_params_realtime_text_enabled(), #LinphoneCoreIsComposingReceivedCb is call everytime a char is received from peer.
- * At the end of remote typing a regular #LinphoneChatMessage is received with committed data from #LinphoneCoreMessageReceivedCb.
+ * At the end of remote typing a regular #LinphoneChatMessage is received with committed data from #LinphoneCoreCbsMessageReceivedCb.
  * @param chat_room #LinphoneChatRoom object @notnil
  * @return  RFC 4103/T.140 char
  */
@@ -314,7 +355,7 @@ LINPHONE_PUBLIC bool_t linphone_chat_room_lime_available(LinphoneChatRoom *chat_
 
 /**
  * Gets the current call associated to this chatroom if any
- * To commit a message, use linphone_chat_room_send_message()
+ * To commit a message, use linphone_chat_message_send()
  * @param chat_room the #LinphoneChatRomm object @notnil
  * @return #LinphoneCall or NULL. @maybenil
  */
@@ -354,9 +395,25 @@ LINPHONE_PUBLIC LinphoneChatRoomState linphone_chat_room_get_state (const Linpho
  * Return whether or not the chat room has been left.
  * @param chat_room #LinphoneChatRoom object @notnil
  * @return TRUE if the chat room has been left, FALSE otherwise.
+ * @deprecated 16/03/2022 use linphone_chat_room_is_read_only() instead.
  */
 LINPHONE_PUBLIC bool_t linphone_chat_room_has_been_left (const LinphoneChatRoom *chat_room);
 
+/**
+ * Return whether or not a message can be sent using this chat room.
+ * A chat room may be read only until it's created, or when it's a group you have left.
+ * @param chat_room #LinphoneChatRoom object @notnil
+ * @return TRUE if a chat message can't be sent in it, FALSE otherwise.
+ */
+LINPHONE_PUBLIC bool_t linphone_chat_room_is_read_only (const LinphoneChatRoom *chat_room);
+
+/**
+ * Return the creation time for the chat room
+ * @param chat_room #LinphoneChatRoom object @notnil
+ * @return the time at which the chat room was created
+ */
+LINPHONE_PUBLIC time_t linphone_chat_room_get_creation_time(const LinphoneChatRoom *chat_room);
+
 /**
  * Return the last updated time for the chat room
  * @param chat_room #LinphoneChatRoom object @notnil
@@ -435,7 +492,7 @@ LINPHONE_PUBLIC int linphone_chat_room_get_nb_participants (const LinphoneChatRo
 /**
  * Get the list of participants of a chat room.
  * @param chat_room A #LinphoneChatRoom object @notnil
- * @return A \bctbx_list{LinphoneParticipant} of the participants
+ * @return A \bctbx_list{LinphoneParticipant} of the participants @maybenil @tobefreed
  */
 LINPHONE_PUBLIC bctbx_list_t * linphone_chat_room_get_participants (const LinphoneChatRoom *chat_room);
 
@@ -513,7 +570,6 @@ LINPHONE_PUBLIC void linphone_chat_room_set_conference_address (LinphoneChatRoom
  */
 LINPHONE_PUBLIC void linphone_chat_room_set_participant_devices(LinphoneChatRoom *chat_room, const LinphoneAddress *participant_address, const bctbx_list_t *device_identities);
 
-
 /**
  * Notify the chatroom that a participant device has just registered.
  * This function is meaningful only for server implementation of chatroom, and shall not by used by client applications.
@@ -587,6 +643,13 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_room_send_chat_message(Li
  */
 LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneChatMessage* linphone_chat_room_create_message(LinphoneChatRoom *chat_room,const char* message);
 
+/**
+ * Converts a #LinphoneChatRoomState enum to a  string.
+ * @param state a #LinphoneChatRoomState to convert to string
+ * @return the string representation of the #LinphoneChatRoomState @notnil
+*/
+LINPHONE_PUBLIC const char* linphone_chat_room_state_to_string(const LinphoneChatRoomState state);
+
 /**
  * @}
  */
