@@ -239,9 +239,9 @@ LINPHONE_PUBLIC LinphoneAuthInfo *linphone_factory_create_auth_info_2(const Linp
  * @param password the password to hash. @notnil
  * @param realm the real to use. @notnil
  * @param algorithm the algorithm to use (MD5 or SHA-256). @notnil
- * @return the generated hash if it succeeded, NULL otherwise. @maybenil
+ * @return the generated hash if it succeeded, NULL otherwise. @maybenil @tobefreed
 */
-LINPHONE_PUBLIC const char * linphone_factory_compute_ha1_for_algorithm(const LinphoneFactory *factory, const char *userid, const char *password, const char *realm, const char *algorithm);
+LINPHONE_PUBLIC char * linphone_factory_compute_ha1_for_algorithm(const LinphoneFactory *factory, const char *userid, const char *password, const char *realm, const char *algorithm);
 
 /**
  * Create a #LinphoneCallCbs object that holds callbacks for events happening on a call.
