@@ -590,7 +590,7 @@ typedef LinphoneCoreCbsNotifyReceivedCb LinphoneCoreNotifyReceivedCb;
  * @param core #LinphoneCore object @notnil
  * @param linphone_event the #LinphoneEvent received @notnil
  * @param subscribe_event The event as string @notnil
- * @param body the #LinphoneContent of the event @notnil
+ * @param body the #LinphoneContent of the event @maybenil
  */
 typedef void (*LinphoneCoreCbsSubscribeReceivedCb)(LinphoneCore *core, LinphoneEvent *linphone_event, const char *subscribe_event, const LinphoneContent *body);
 
@@ -640,6 +640,15 @@ typedef void (*LinphoneCoreCbsConferenceInfoReceivedCb)(LinphoneCore *core, cons
  */
 typedef void (*LinphoneCoreCbsPushNotificationReceivedCb)(LinphoneCore *core, const char *payload);
 
+/**
+ * Callback to notify that there are errors from the video rendering.
+ * Check #LinphoneCallCbsVideoDisplayErrorOccurredCb for more details.
+ *
+ * @param core #LinphoneCore object @notnil
+ * @param error_code The error code. It depends of the display filter (available for OpenGL)
+ **/
+typedef void (*LinphoneCoreCbsPreviewDisplayErrorOccurredCb)(LinphoneCore *core, int error_code);
+
 /**
  * @}
 **/
