@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone.
+ * This file is part of Liblinphone 
+ * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -85,6 +86,14 @@ LINPHONE_PUBLIC LinphonePlayerCbs *linphone_player_get_current_callbacks(const L
 
 /**
  * Open a file for playing.
+ *
+ * Actually, only WAVE and MKV/MKA file formats are supported and a limited set of codecs depending
+ * of the selected format. Here are the list of working combinations:
+ * * WAVE format: only PCM s16le codec is supported.
+ * * MKV/MKA format:
+ *   * Supported audo codecs: Opus, PCMU, PCM s16le.
+ *   * Supported video codecs: VP8, H264.
+ *
  * @param player #LinphonePlayer object @notnil
  * @param filename The path to the file to open @notnil
  */
@@ -146,6 +155,13 @@ LINPHONE_PUBLIC void linphone_player_close(LinphonePlayer *player);
  */
 LINPHONE_PUBLIC void linphone_player_set_window_id(LinphonePlayer *player, void *window_id);
 
+/**
+ * Create a window id to be used to display video if any.
+ * @param player #LinphonePlayer object @notnil
+ * @return window_id The window id pointer to use. @maybenil
+ */
+LINPHONE_PUBLIC void *linphone_player_create_window_id(LinphonePlayer *player);
+
 /**
  * Returns whether the file has video and if it can be displayed
  * @param player #LinphonePlayer object @notnil
